;
; Port Control
;

include fossil.inc

  ifdef LANG_C
	.MODEL Large,C
  else
	.MODEL Large,Pascal
  endif

  ifdef LANG_PAS
Code	Segment Word Public
	assume CS:Code
  else
.CODE
  endif

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComPortInit		Initialise a communications port
;;	int ComPortInit(port, flagptr, infoptr)
;;		int port				port number to initialise (0=COM1)
;;		void far *flagptr		pointer to ^C flag (optional)
;;		struct finfo *infoptr	pointer to FOSSIL information struct
;;	Returns 0x1954 if installed, -1 if not, DTR raised, baud rate preserved
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComPortInit

ComPortInit PROC uses ES, port:WORD, flagptr:PTR, infoptr:PTR
	xor BX, BX
	les CX, flagptr
	mov AX, ES
	or AX, CX
	jz @N
	mov BX, SETBRK
@N:
	comms initport, port
	cmp AX, FSIG
	jne @i_err
	push DI
	les DI,infoptr
	or DI, DI
	jz @X
	mov [DI].maxfunc, BL
	mov [DI].revfoss, BH
@X:
	pop DI
@i_err:
	ret
ComPortInit ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComPortStat		Get Port Status
;;	int ComPortStat(port)
;;		int port		Port number to read status from
;;	Returns status word as follows:
;;			AH[0:0] 1 = Characters in input buffer
;;			AH[1:1] 1 = Input buffer overrun
;;			AL[3:3] 1 = Always (never 0)
;;			AH[5:5] 1 = Output buffer not full
;;			AH[6:6] 1 = Output buffer empty
;;			AL[7:7] 1 = Carrier Detect signal
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComPortStat

ComPortStat PROC, port:WORD
	comms portstat,port
	ret
ComPortStat ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComPortDeInit	Deinitialise Communications Driver
;;	void ComPortDeInit(port)
;;		int port		Port number to deinitalise
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComPortDeInit

ComPortDeInit PROC, port:WORD
	comms deinitport,port
	ret
ComPortDeInit ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComPortSet		Setup port communication settings
;;	int ComPortSet(port, parms)
;;		int port	port number to set up (0=COM1)
;;		int parms	parameters to set where:
;;			Bits	[7:5]	000 = 19200, 001 = 38400, 010 = 300, 011 = 600,
;;							100 = 1200,	101 = 2400, 110 = 4800, 111 = 9600.
;;			Parity	[4:3]	00 or 10 = none, 01 = odd, 11 = even.
;;			StopBits [2:2]	0 = 1, 1 = 2
;;			ChrLen 5 bits plus value [1:0]
;;			Support for [4:0] = 00011 required of driver, others optional
;;	Returns current modem status
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComPortSet

ComPortSet PROC, port:WORD, parms:BYTE
	mov AL,parms
	comms setport,port
	ret
ComPortSet ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComSetDtr		Set state of hardware DTR
;;	int ComSetDtr(port, state)
;;		int port		Port number to change DTR state
;;		int state		1 = Set DTR, 0 = Lower DTR
;;	Returns state of DTR
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComSetDtr

ComSetDtr PROC, port:WORD, state:BYTE
	mov AL,state
	comms dtrctl,port
	xor AH,AH
	ret
ComSetDtr ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComFlowCtl		Flow control
;;	void ComFlowCtl(port, mask)
;;		int port	Port number to purge
;;		int fmask	Flow control mask
;;			AL[0:0] 1= enables remote to restrain FOSSIL transmitter using
;;						XON/XOFF
;;			AL[1:1] 1= enables modem restraint of FOSSIL transmitter using
;;						CTS and FOSSIL restraint of modem using RTS
;;			AL[3:3] 1= enables FOSSIL to restrain remote using XON/XOFF.              |
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComFlowCtl

ComFlowCtl PROC, port:WORD, fmask:WORD
	mov AX,fmask
	comms flowctl,port
	ret
ComFlowCtl ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComBrkChk		Enable/disable break check
;;	int ComBrkChk(port, mask)
;;		int port	Port number to purge
;;		int bmask	Flags byte
;;			AL[0:0] 1 = enable/disable CtlC/CtlK check (driver will set
;;						internal flag which is returned by this function when
;;						it detects a CtlC/CtlK).
;;			AL[1:1] 1 = stop transmitter 0 = release previous stop
;;					   This is used primarily for programs that can't trust
;;						XON/XOFF at FOSSIL level (such as BBS software)
;;	Returns 1 if CtlC/K detected
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComBrkChk

ComBrkChk PROC, port:WORD, bmask:WORD
	mov AX,bmask
	comms flowctl,port
	ret
ComBrkChk ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComTxBrk		Start/stop sending break
;;	void ComTxBrk(port, flag)
;;		int port		Port number to read
;;		int flag		1 = Start break, 0 = End break
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComTxBrk

ComTxBrk PROC, port:WORD, flag:BYTE
	mov AL,flag
	comms break,port
	ret
ComTxBrk ENDP



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;	ComDrvInfo			Get driver info
;;	void ComDrvInfo(port, buf, sz)
;;		int port		Port number
;;		void far*buf	Buffer address
;;		int sz			Size of buffer
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	public ComDrvInfo

ComDrvInfo PROC uses ES DI, port:WORD, buf:DWORD, sz:WORD
	mov CX,sz
	les DI,buf
	comms drvinfo,port
	ret
ComDrvInfo ENDP

  ifdef LANG_PAS
Code	ENDS
  endif

END
